==> jc-1.4.0.tar.gz: polyglot/util/FilteringIterator.h <==
// public final class polyglot.util.FilteringIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 97c2e63cc786be polyglot_util_FilteringIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_FilteringIterator_H_
#define _JC_polyglot_util_FilteringIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_polyglot_util_Predicate$object;

// Typedefs
typedef struct _jc_polyglot_util_FilteringIterator$sub_refs	_jc_polyglot_util_FilteringIterator$sub_refs;
typedef struct _jc_polyglot_util_FilteringIterator$sub_nonrefs	_jc_polyglot_util_FilteringIterator$sub_nonrefs;
typedef struct _jc_polyglot_util_FilteringIterator$refs	_jc_polyglot_util_FilteringIterator$refs;
typedef struct _jc_polyglot_util_FilteringIterator$nonrefs	_jc_polyglot_util_FilteringIterator$nonrefs;
typedef struct _jc_polyglot_util_FilteringIterator$object	_jc_polyglot_util_FilteringIterator$object;

typedef const struct _jc_polyglot_util_FilteringIterator$vmethods	_jc_polyglot_util_FilteringIterator$vmethods;
typedef const struct _jc_polyglot_util_FilteringIterator$vtable	_jc_polyglot_util_FilteringIterator$vtable;
typedef const struct _jc_polyglot_util_FilteringIterator$vtype	_jc_polyglot_util_FilteringIterator$vtype;

// Constructors
extern void _jc_polyglot_util_FilteringIterator$method$_init$5c4c6ee76fdd39ab(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_polyglot_util_FilteringIterator$method$_init$82006ff6ade39c8d(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_polyglot_util_FilteringIterator$method$findNextItem$9bafc5b15da302df(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *);
extern jboolean _jc_polyglot_util_FilteringIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_FilteringIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *);
extern void _jc_polyglot_util_FilteringIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_FilteringIterator$method_info$findNextItem$9bafc5b15da302df;
extern _jc_method _jc_polyglot_util_FilteringIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_polyglot_util_FilteringIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_polyglot_util_FilteringIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_polyglot_util_FilteringIterator$vmethods {
	void	(*findNextItem$9bafc5b15da302df)(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *);
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *);
};

// Vtable
struct _jc_polyglot_util_FilteringIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_FilteringIterator$vmethods	polyglot_util_FilteringIterator;
};

// Vtype
struct _jc_polyglot_util_FilteringIterator$vtype {
	_jc_type			type;
	_jc_polyglot_util_FilteringIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_FilteringIterator$sub_refs {
	struct _jc_java_lang_Object$object	*next__5fitem;
	struct _jc_object	*backing__5fiterator;
	struct _jc_object	*predicate;
};

// Reference instance fields (object)
struct _jc_polyglot_util_FilteringIterator$refs {
    _jc_polyglot_util_FilteringIterator$sub_refs	polyglot_util_FilteringIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_FilteringIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_FilteringIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_FilteringIterator$sub_nonrefs	polyglot_util_FilteringIterator;
};

// Object instance structure
struct _jc_polyglot_util_FilteringIterator$object {
	_jc_polyglot_util_FilteringIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_FilteringIterator$vtype	*vtype;
	_jc_polyglot_util_FilteringIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_FilteringIterator$vtype _jc_polyglot_util_FilteringIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_FilteringIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_FilteringIterator$class_object;

#endif	/* _JC_polyglot_util_FilteringIterator_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/FilteringIterator.h <==
// public final class polyglot.util.FilteringIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 97c2e63cc786be polyglot_util_FilteringIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_FilteringIterator_H_
#define _JC_polyglot_util_FilteringIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Iterator$object;
struct _jc_polyglot_util_Predicate$object;

// Typedefs
typedef struct _jc_polyglot_util_FilteringIterator$sub_refs	_jc_polyglot_util_FilteringIterator$sub_refs;
typedef struct _jc_polyglot_util_FilteringIterator$sub_nonrefs	_jc_polyglot_util_FilteringIterator$sub_nonrefs;
typedef struct _jc_polyglot_util_FilteringIterator$refs	_jc_polyglot_util_FilteringIterator$refs;
typedef struct _jc_polyglot_util_FilteringIterator$nonrefs	_jc_polyglot_util_FilteringIterator$nonrefs;
typedef struct _jc_polyglot_util_FilteringIterator$object	_jc_polyglot_util_FilteringIterator$object;

typedef const struct _jc_polyglot_util_FilteringIterator$vmethods	_jc_polyglot_util_FilteringIterator$vmethods;
typedef const struct _jc_polyglot_util_FilteringIterator$vtable	_jc_polyglot_util_FilteringIterator$vtable;
typedef const struct _jc_polyglot_util_FilteringIterator$vtype	_jc_polyglot_util_FilteringIterator$vtype;

// Constructors
extern void _jc_polyglot_util_FilteringIterator$method$_init$5c4c6ee76fdd39ab(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_FilteringIterator$method$_init$82006ff6ade39c8d(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_util_FilteringIterator$method$findNextItem$9bafc5b15da302df(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_util_FilteringIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_polyglot_util_FilteringIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_FilteringIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_FilteringIterator$method_info$findNextItem$9bafc5b15da302df;
extern _jc_method _jc_polyglot_util_FilteringIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_polyglot_util_FilteringIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_polyglot_util_FilteringIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_polyglot_util_FilteringIterator$vmethods {
	void	(*findNextItem$9bafc5b15da302df)(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_polyglot_util_FilteringIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_FilteringIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_FilteringIterator$vmethods	polyglot_util_FilteringIterator;
};

// Vtype
struct _jc_polyglot_util_FilteringIterator$vtype {
	_jc_type			type;
	_jc_polyglot_util_FilteringIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_FilteringIterator$sub_refs {
	struct _jc_java_lang_Object$object	*next__5fitem;
	struct _jc_object	*backing__5fiterator;
	struct _jc_object	*predicate;
};

// Reference instance fields (object)
struct _jc_polyglot_util_FilteringIterator$refs {
    _jc_polyglot_util_FilteringIterator$sub_refs	polyglot_util_FilteringIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_FilteringIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_FilteringIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_FilteringIterator$sub_nonrefs	polyglot_util_FilteringIterator;
};

// Object instance structure
struct _jc_polyglot_util_FilteringIterator$object {
	_jc_polyglot_util_FilteringIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_FilteringIterator$vtype	*vtype;
	_jc_polyglot_util_FilteringIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_FilteringIterator$vtype _jc_polyglot_util_FilteringIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_FilteringIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_FilteringIterator$class_object;

#endif	/* _JC_polyglot_util_FilteringIterator_H_ */
